Actually useful class which takes an R dataframe and a filename

Version: 1.1.0.9000

Generated: 2024-12-19T17:17:03.386

Details

string and serialises the dataframe so it can be used natively in java for testing purposes.

Methods

Constructors

Class methods

  • none

  • instance$clone()

  • instance$print()


Constructor new()

the default no-args constructor

Usage


J = testRapi::JavaApi$get()
instance = J$Serialiser$new();
        

Arguments

  • none

Returns

the new R6 Serialiser object

Examples

## -----------------------------------
## Construct new instance of Serialiser
## -----------------------------------
if (FALSE) { # \dontrun{
J = testRapi::JavaApi$get()
# appropriate parameter values must be provided
instance = J$Serialiser$new()
} # }