Serialiser.RdActually useful class which takes an R dataframe and a filename
Version: 1.1.0.9000
Generated: 2024-12-19T17:17:03.386
string and serialises the dataframe so it can be used natively in java for testing purposes.
## -----------------------------------
## Construct new instance of Serialiser
## -----------------------------------
if (FALSE) { # \dontrun{
J = testRapi::JavaApi$get()
# appropriate parameter values must be provided
instance = J$Serialiser$new()
} # }